import { Request } from "express";
import { Session } from "../models/session";
import { User } from "../models/user";
import { HEADER_X_AUTHORIZATION } from "../utils/constants";
import { getUserSession } from "../utils/utils";

export async function sessionProtection(req: Request, res: any, next: any) {
  const session = await getUserSession(req);

  if (!session) {
    return res.status(401).json({ status: "err" });
  }

  next();
}

export async function adminProtection(req: Request, res: any, next: any) {
  const xAuthorization = req.get(HEADER_X_AUTHORIZATION);

  if (!xAuthorization) {
    return res.status(401).json({ status: "err" });
  }

  const session = await Session.findOne({ sessionId: xAuthorization })
    .select("sessionId accountName -_id")
    .lean();

  if (!session) {
    return res.status(401).json({ status: "err" });
  }

  const user = await User.findOne({ accountName: session.accountName })
    .select("isAdmin -_id")
    .lean();

  if (!user || !user.isAdmin) {
    return res.status(401).json({ status: "err" });
  }

  next();
}
